<?php

namespace Tests\Feature;

use App\Models\Server;
use App\Models\User;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Tests\TestCase;

class ServerProfileTest extends TestCase
{
    use RefreshDatabase;
    
    public function test_show() {
        $user = User::create([
            'username' => 'test',
            'email' => 'test@localhost',
            'password' => Hash::make('test'),
        ]);

        $server = Server::create([
            'login' => 'test',
            'password' => Hash::make('test'),
            'owner_id' => $user->id,
            'public' => true
        ]);
        $token = Auth::login($server);

        $response = $this->withHeaders([
            "Authorization" => "Bearer " . $token
        ])->get('/api/auth/server/profile');
        $response->assertStatus(200);
        $response->assertJsonStructure([
            "server" => [
                "id",
                "login",
                "public",
                "created_at",
                "updated_at",
                "owner_id"
            ]
        ]);
    }

}
